@@ -18,11 +18,9 @@ rescue LoadError
       end
     end
 
+    ruby_plat = RUBY_PLATFORM.gsub("i386", "x86")
     # Temporary add this directory for DLL search, so that bundled DLLs can be found.
-    ports_dir = RbConfig::CONFIG["host"].gsub('i686-pc-mingw32') do
-      major_minor < '2.0' ? 'i586-mingw32msvc' : 'i686-w64-mingw32'
-    end
-    ports_bin = File.expand_path("../../ports/#{ports_dir}/bin", __FILE__)
+    ports_bin = File.expand_path("../../ports/#{ruby_plat}/bin", __FILE__)
     add_dll_path.call(ports_bin) do
       require "#{major_minor}/fox16_c"
     end
